@@ -11,7 +11,7 @@ require Rose::DB::Object::Util;
 
 use Carp;
 
-our $VERSION = '0.783';
+our $VERSION = '0.784';
 
 __PACKAGE__->export_tags
 (
@@ -98,26 +98,33 @@ sub load_or_insert
 {
   my($self) = shift;
 
-  my($ret, @ret);
+  my($ret, @ret, $loaded, $error);
 
-  # Ignore any errors due to missing primary/unique keys
-  my $loaded = eval
-  {  
-    if(wantarray)
-    {
-      @ret = $self->load(@_, speculative => 1);
-      return $ret[0]  if($ret[0]); # return from eval
-    }
-    else
-    {
-      $ret = $self->load(@_, speculative => 1);
-      return $ret  if($ret); # return from eval
-    }
+  TRY:
+  {
+    local $@;
 
-    return 0; # return from eval
-  };
+    # Ignore any errors due to missing primary/unique keys
+    $loaded = eval
+    {  
+      if(wantarray)
+      {
+        @ret = $self->load(@_, speculative => 1);
+        return $ret[0]  if($ret[0]); # return from eval
+      }
+      else
+      {
+        $ret = $self->load(@_, speculative => 1);
+        return $ret  if($ret); # return from eval
+      }
 
-  if(my $error = $@)
+      return 0; # return from eval
+    };
+
+    $error = $@;
+  }
+
+  if($error)
   {
     # ...but re-throw all other errors
     unless(UNIVERSAL::isa($error, 'Rose::DB::Object::Exception') &&
@@ -137,26 +144,33 @@ sub load_or_save
 {
   my($self) = shift;
 
-  my($ret, @ret);
+  my($ret, @ret, $loaded, $error);
 
-  # Ignore any errors due to missing primary/unique keys
-  my $loaded = eval
-  {  
-    if(wantarray)
-    {
-      @ret = $self->load(@_, speculative => 1);
-      return $ret[0]  if($ret[0]); # return from eval
-    }
-    else
-    {
-      $ret = $self->load(@_, speculative => 1);
-      return $ret  if($ret); # return from eval
-    }
+  TRY:
+  {
+    local $@;
 
-    return 0; # return from eval
-  };
+    # Ignore any errors due to missing primary/unique keys
+    $loaded = eval
+    {  
+      if(wantarray)
+      {
+        @ret = $self->load(@_, speculative => 1);
+        return $ret[0]  if($ret[0]); # return from eval
+      }
+      else
+      {
+        $ret = $self->load(@_, speculative => 1);
+        return $ret  if($ret); # return from eval
+      }
 
-  if(my $error = $@)
+      return 0; # return from eval
+    };
+
+    $error = $@;
+  }
+
+  if($error)
   {
     # ...but re-throw all other errors
     unless(UNIVERSAL::isa($error, 'Rose::DB::Object::Exception') &&
@@ -180,6 +194,7 @@ sub insert_or_update
   # Initially trust the metadata
   if($self->{STATE_IN_DB()})
   {
+    local $@;
     eval { $self->save(@_, update => 1) };
     return $self || 1  unless($@); 
   }
@@ -192,12 +207,19 @@ sub insert_or_update
   # ...but this is a lot faster
   my $clone = bless { %$self }, ref($self);
 
-  my $loaded;
+  my($loaded, $error);
 
-  # Ignore any errors due to missing primary/unique keys
-  eval { $loaded = $clone->load(speculative => 1) };
+  TRY:
+  {
+    local $@;
 
-  if(my $error = $@)
+    # Ignore any errors due to missing primary/unique keys
+    eval { $loaded = $clone->load(speculative => 1) };
+
+    $error = $@;
+  }
+
+  if($error)
   {
     # ...but re-throw all other errors
     unless(UNIVERSAL::isa($error, 'Rose::DB::Object::Exception') &&
@@ -1528,6 +1550,6 @@ John C. Siracusa (siracusa@gmail.com)
 
 =head1 LICENSE
 
-Copyright (c) 2009 by John C. Siracusa.  All rights reserved.  This program is
+Copyright (c) 2010 by John C. Siracusa.  All rights reserved.  This program is
 free software; you can redistribute it and/or modify it under the same terms
 as Perl itself.
