@@ -11,14 +11,15 @@ our @ISA = qw(Rose::DB::Object::Metadata::Relationship);
 use Rose::Object::MakeMethods::Generic;
 use Rose::DB::Object::MakeMethods::Generic;
 
-our $VERSION = '0.780';
+our $VERSION = '0.781';
 
 __PACKAGE__->default_auto_method_types(qw(get_set_on_save delete_on_save));
 
 __PACKAGE__->add_common_method_maker_argument_names
 (
   qw(class share_db key_columns required manager_class manager_method 
-     manager_args query_args join_args object_args)
+     manager_count_method manager_iterator_method manager_find_method
+     manager_delete_method manager_args query_args join_args object_args)
 );
 
 use Rose::Object::MakeMethods::Generic
@@ -375,6 +376,18 @@ Get or set the name of the L<Rose::DB::Object::Manager>-derived class used to fe
 
 Get or set the name of the L<manager_class|/manager_class> class method to call when fetching the object.
 
+=item B<manager_count_method [METHOD]>
+
+Get or set the name of the L<manager_class|/manager_class> class method to call when counting objects.  The L<make_methods|Rose::DB::Object::Metadata::Relationship/make_methods> method will use L<get_objects_count|Rose::DB::Object::Manager/get_objects_count> if this value is left undefined.
+
+=item B<manager_iterator_method [METHOD]>
+
+Get or set the name of the L<manager_class|/manager_class> class method to call when creating an iterator.  The L<make_methods|Rose::DB::Object::Metadata::Relationship/make_methods> method will use L<get_objects_iterator|Rose::DB::Object::Manager/get_objects_iterator> if this value is left undefined.
+
+=item B<manager_delete_method [METHOD]>
+
+Get or set the name of the L<manager_class|/manager_class> class method to call when deleting objects.  The L<make_methods|Rose::DB::Object::Metadata::Relationship/make_methods> method will use L<delete_objects|Rose::DB::Object::Manager/delete_objects> if this value is left undefined.
+
 =item B<manager_args [HASHREF]>
 
 Get or set a reference to a hash of name/value arguments to pass to the L<manager_method|/manager_method> when fetching the object.  See the documentation for L<Rose::DB::Object::Manager>'s L<get_objects|Rose::DB::Object::Manager/get_objects> method for a full list of valid arguments for use with the C<manager_args> parameter.
@@ -417,6 +430,6 @@ John C. Siracusa (siracusa@gmail.com)
 
 =head1 LICENSE
 
-Copyright (c) 2009 by John C. Siracusa.  All rights reserved.  This program is
+Copyright (c) 2010 by John C. Siracusa.  All rights reserved.  This program is
 free software; you can redistribute it and/or modify it under the same terms
 as Perl itself.
